@@ -298,6 +298,10 @@ def test_os_build_compare():
         "0.12.1+git20120407.aaa852f-1+deb7u1",
     )
     assert res
+    res = utils.version_compare("2.36.1-8+deb11u1", 0, "*", None, "2.36.1-8+deb11u1")
+    assert not res
+    res = utils.version_compare("1.10-4+deb11u1", 0, "*", None, "1.10-4+deb11u1")
+    assert not res
 
 
 def test_parse_uri():
