@@ -3,12 +3,12 @@ osv to NVD CVE converter
 
 This module fetches the vulnerability data from osv.dev and stores them in NVD CVE 1.1 json format.
 """
-import os
 from zipfile import ZipFile
 
 import requests
 
-from vdb.lib import config as config, CustomNamedTemporaryFile
+from vdb.lib import CustomNamedTemporaryFile
+from vdb.lib import config as config
 from vdb.lib.nvd import NvdSource
 from vdb.lib.utils import (
     convert_score_severity,
