@@ -293,7 +293,7 @@ def convert_to_semver(version):
     # Trim based on known prerelease strings
     if ver.get("prerelease"):
         try:
-            prefloat = float(ver.get("prerelease"))
+            prefloat = float(ver.get("prerelease", 0))
             ver["prerelease"] = int(prefloat)
         except Exception:
             pre_str = ver.get("prerelease", "").lower()
@@ -656,7 +656,7 @@ def get_default_cve_data(severity):
         score = 2.0
         attackComplexity = "HIGH"
         vectorString = "CVSS:3.1/AV:N/AC:H/PR:N/UI:N/S:U/C:L/I:N/A:N"
-    elif severity in ["MODERATE", "MODERATE"]:
+    elif severity in ["MODERATE", "MODERATE", "MEDIUM"]:
         score = 5.0
         severity = "MEDIUM"
         vectorString = "CVSS:3.1/AV:N/AC:H/PR:N/UI:N/S:U/C:L/I:L/A:L"
